@@ -404,6 +404,9 @@ UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 # 密钥已绑定使用计划。
 UNSUPPORTEDOPERATION_ALREADYBINDUSAGEPLAN = 'UnsupportedOperation.AlreadyBindUsagePlan'
 
+# 当前插件不支持绑定。
+UNSUPPORTEDOPERATION_ATTACHPLUGIN = 'UnsupportedOperation.AttachPlugin'
+
 # 协议为HTTP时，不支持强制Https。
 UNSUPPORTEDOPERATION_FORCEHTTPS = 'UnsupportedOperation.ForceHttps'
 
@@ -422,6 +425,9 @@ UNSUPPORTEDOPERATION_INVALIDSTATUS = 'UnsupportedOperation.InvalidStatus'
 # 不支持修改EIAM类型授权API。
 UNSUPPORTEDOPERATION_MODIFYEIAMAUTHAPI = 'UnsupportedOperation.ModifyEIAMAuthApi'
 
+# 网络类型不支持修改。
+UNSUPPORTEDOPERATION_MODIFYNETTYPE = 'UnsupportedOperation.ModifyNetType'
+
 # 前端协议类型不支持修改。
 UNSUPPORTEDOPERATION_MODIFYPROTOCOL = 'UnsupportedOperation.ModifyProtocol'
 
